summaryrefslogtreecommitdiffstats
path: root/config-model
diff options
context:
space:
mode:
authorJon Bratseth <bratseth@yahoo-inc.com>2016-12-04 17:08:18 -0800
committerJon Bratseth <bratseth@yahoo-inc.com>2016-12-04 17:08:18 -0800
commitc3689bfbf40620b7adb8f057c38d087e3dcc0a15 (patch)
tree2d5581c0273b085a5f23e9a1f86661a956850e26 /config-model
parent30228290d99ff898ded1869d5f704a5e4728d2b1 (diff)
Correct over-eager renaming
Diffstat (limited to 'config-model')
-rw-r--r--config-model/src/main/java/com/yahoo/config/model/ConfigModelRepo.java2
-rw-r--r--config-model/src/main/java/com/yahoo/config/model/builder/xml/ConfigModelBuilder.java6
-rw-r--r--config-model/src/main/java/com/yahoo/config/model/graph/ModelGraphBuilder.java2
-rw-r--r--config-model/src/main/java/com/yahoo/config/model/provision/HostsXmlProvisioner.java2
-rw-r--r--config-model/src/main/java/com/yahoo/vespa/model/PortsMeta.java2
-rw-r--r--config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/DomAdminV4Builder.java2
-rw-r--r--config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/DomConfigPayloadBuilder.java12
-rw-r--r--config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/NodesSpecification.java4
-rw-r--r--config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/VespaDomBuilder.java2
-rw-r--r--config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/chains/ComponentsBuilder.java4
-rw-r--r--config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/chains/GenericChainedComponentModelBuilder.java2
-rw-r--r--config-model/src/main/java/com/yahoo/vespa/model/container/search/PageTemplates.java2
-rw-r--r--config-model/src/main/java/com/yahoo/vespa/model/container/xml/ManhattanContainerModelBuilder.java2
-rw-r--r--config-model/src/main/java/com/yahoo/vespa/model/routing/DocumentProtocol.java2
14 files changed, 23 insertions, 23 deletions
diff --git a/config-model/src/main/java/com/yahoo/config/model/ConfigModelRepo.java b/config-model/src/main/java/com/yahoo/config/model/ConfigModelRepo.java
index a6f2c2f191b..d4b6751c356 100644
--- a/config-model/src/main/java/com/yahoo/config/model/ConfigModelRepo.java
+++ b/config-model/src/main/java/com/yahoo/config/model/ConfigModelRepo.java
@@ -84,7 +84,7 @@ public class ConfigModelRepo implements ConfigModelRepoAdder, Serializable, Iter
}
/**
- * If the top level is &lt;services&gt;, it contains a list of services labels,
+ * If the top level is &lt;services&gt;, it contains a list of services elements,
* otherwise, the top level tag is a single service.
*/
private List<Element> getServiceElements(Element servicesRoot) {
diff --git a/config-model/src/main/java/com/yahoo/config/model/builder/xml/ConfigModelBuilder.java b/config-model/src/main/java/com/yahoo/config/model/builder/xml/ConfigModelBuilder.java
index 15fa0ccdaa8..15068eceaf9 100644
--- a/config-model/src/main/java/com/yahoo/config/model/builder/xml/ConfigModelBuilder.java
+++ b/config-model/src/main/java/com/yahoo/config/model/builder/xml/ConfigModelBuilder.java
@@ -31,10 +31,10 @@ public abstract class ConfigModelBuilder<MODEL extends ConfigModel> extends Abst
}
/**
- * Method that must return the XML labels this builder handles. Subclasses must implement this in order to
- * get called when one of the labels have been encountered when parsing.
+ * Method that must return the XML elements this builder handles. Subclasses must implement this in order to
+ * get called when one of the elements have been encountered when parsing.
*
- * @return A list of labels that this builder handles.
+ * @return A list of elements that this builder handles.
*/
public abstract List<ConfigModelId> handlesElements();
diff --git a/config-model/src/main/java/com/yahoo/config/model/graph/ModelGraphBuilder.java b/config-model/src/main/java/com/yahoo/config/model/graph/ModelGraphBuilder.java
index 2f3b6dd390f..97d914c6012 100644
--- a/config-model/src/main/java/com/yahoo/config/model/graph/ModelGraphBuilder.java
+++ b/config-model/src/main/java/com/yahoo/config/model/graph/ModelGraphBuilder.java
@@ -8,7 +8,7 @@ import java.util.ArrayList;
import java.util.List;
/**
- * Used to add builders and labels in addBuilder, and then build a dependency graph based on the
+ * Used to add builders and elements in addBuilder, and then build a dependency graph based on the
* constructor arguments.
*
* @author lulf
diff --git a/config-model/src/main/java/com/yahoo/config/model/provision/HostsXmlProvisioner.java b/config-model/src/main/java/com/yahoo/config/model/provision/HostsXmlProvisioner.java
index 1d76cbb82e3..ae77cf32920 100644
--- a/config-model/src/main/java/com/yahoo/config/model/provision/HostsXmlProvisioner.java
+++ b/config-model/src/main/java/com/yahoo/config/model/provision/HostsXmlProvisioner.java
@@ -27,7 +27,7 @@ public class HostsXmlProvisioner implements HostProvisioner {
@Override
public HostSpec allocateHost(String alias) {
- // Some special rules to allow no admin labels as well as jdisc element without nodes.
+ // Some special rules to allow no admin elements as well as jdisc element without nodes.
if (alias.equals(IMPLICIT_ADMIN_HOSTALIAS)) {
if (hosts.asCollection().size() > 1) {
throw new IllegalArgumentException("More than 1 host specified (" + hosts.asCollection().size() + ") and <admin> not specified");
diff --git a/config-model/src/main/java/com/yahoo/vespa/model/PortsMeta.java b/config-model/src/main/java/com/yahoo/vespa/model/PortsMeta.java
index e511e377379..a0b3cc7294b 100644
--- a/config-model/src/main/java/com/yahoo/vespa/model/PortsMeta.java
+++ b/config-model/src/main/java/com/yahoo/vespa/model/PortsMeta.java
@@ -13,7 +13,7 @@ import java.util.List;
*/
public class PortsMeta implements Serializable {
- /** A list of all ports. The list labels are lists of strings. */
+ /** A list of all ports. The list elements are lists of strings. */
private List<LinkedList<String>> ports;
/** Remember the rpc admin port offset. */
diff --git a/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/DomAdminV4Builder.java b/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/DomAdminV4Builder.java
index 6d401884090..c0baa50b3b0 100644
--- a/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/DomAdminV4Builder.java
+++ b/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/DomAdminV4Builder.java
@@ -41,7 +41,7 @@ public class DomAdminV4Builder extends DomAdminBuilderBase {
ModelElement adminElement = new ModelElement(w3cAdminElement);
admin.addConfigservers(getConfigServersFromSpec(admin));
- // Note: These two labels only exists in admin version 4.0
+ // Note: These two elements only exists in admin version 4.0
// This build handles admin version 3.0 by ignoring its content (as the content is not useful)
Optional<NodesSpecification> requestedSlobroks = NodesSpecification.optionalDedicatedFromParent(adminElement.getChild("slobroks"));
Optional<NodesSpecification> requestedLogservers = NodesSpecification.optionalDedicatedFromParent(adminElement.getChild("logservers"));
diff --git a/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/NodesSpecification.java b/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/NodesSpecification.java
index 810d4177291..c83f6098a0f 100644
--- a/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/NodesSpecification.java
+++ b/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/NodesSpecification.java
@@ -63,7 +63,7 @@ public class NodesSpecification {
/**
* Returns a requirement for dedicated nodes taken from the <code>nodes</code> element
- * contained in the given parent element, or empty if the parent element is null, or the nodes labels
+ * contained in the given parent element, or empty if the parent element is null, or the nodes elements
* is not present.
*/
public static Optional<NodesSpecification> fromParent(ModelElement parentElement) {
@@ -75,7 +75,7 @@ public class NodesSpecification {
/**
* Returns a requirement for undedicated or dedicated nodes taken from the <code>nodes</code> element
- * contained in the given parent element, or empty if the parent element is null, or the nodes labels
+ * contained in the given parent element, or empty if the parent element is null, or the nodes elements
* is not present.
*/
public static Optional<NodesSpecification> optionalDedicatedFromParent(ModelElement parentElement) {
diff --git a/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/VespaDomBuilder.java b/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/VespaDomBuilder.java
index 9f558e59d4f..e24fae3e3b5 100644
--- a/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/VespaDomBuilder.java
+++ b/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/VespaDomBuilder.java
@@ -192,7 +192,7 @@ public class VespaDomBuilder extends VespaModelBuilder {
}
/**
- * The SimpleConfigProducer is the producer for labels such as qrservers, topleveldispatchers, gateways.
+ * The SimpleConfigProducer is the producer for elements such as qrservers, topleveldispatchers, gateways.
* Must support overrides for that too, hence this builder
*
* @author vegardh
diff --git a/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/chains/ComponentsBuilder.java b/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/chains/ComponentsBuilder.java
index 2598e501c9b..b7aef6b9b1f 100644
--- a/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/chains/ComponentsBuilder.java
+++ b/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/chains/ComponentsBuilder.java
@@ -59,7 +59,7 @@ public class ComponentsBuilder<T extends ChainedComponent<?>> {
/**
* @param ancestor The parent config producer
* @param componentTypes The allowed component types for 'elementContainingComponentElements' - MUST match &lt;T&gt;
- * @param elementsContainingComponentElems All labels containing labels with name matching ComponentType.name
+ * @param elementsContainingComponentElems All elements containing elements with name matching ComponentType.name
* @param outerComponentTypeByComponentName Use null if this is the outermost scope, i.e.
* every component is a definition, not a reference.
*/
@@ -126,7 +126,7 @@ public class ComponentsBuilder<T extends ChainedComponent<?>> {
if (componentSpec.getAttributes().getLength() > 1 || !XML.getChildren(componentSpec).isEmpty())
throw new RuntimeException("Expecting " + componentName +
" to be a reference to a global component with the same name," +
- " so no additional attributes or nested labels are allowed");
+ " so no additional attributes or nested elements are allowed");
}
private void ensureTypesMatch(ComponentType type1, ComponentType type2, String componentName) {
diff --git a/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/chains/GenericChainedComponentModelBuilder.java b/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/chains/GenericChainedComponentModelBuilder.java
index d913bf11e44..a7f5a306f8b 100644
--- a/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/chains/GenericChainedComponentModelBuilder.java
+++ b/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/chains/GenericChainedComponentModelBuilder.java
@@ -8,7 +8,7 @@ import com.yahoo.config.model.builder.xml.XmlHelper;
import org.w3c.dom.Element;
/**
- * reads the common attributes and labels of all chained component labels.
+ * reads the common attributes and elements of all chained component elements.
* @author tonytv
*/
public abstract class GenericChainedComponentModelBuilder {
diff --git a/config-model/src/main/java/com/yahoo/vespa/model/container/search/PageTemplates.java b/config-model/src/main/java/com/yahoo/vespa/model/container/search/PageTemplates.java
index b806fe9b157..c38001d4a83 100644
--- a/config-model/src/main/java/com/yahoo/vespa/model/container/search/PageTemplates.java
+++ b/config-model/src/main/java/com/yahoo/vespa/model/container/search/PageTemplates.java
@@ -50,7 +50,7 @@ public class PageTemplates implements Serializable, PageTemplatesConfig.Producer
}
// We are representing these as XML rather than a structured config type because the structure
- // is not easily representable by config (arbitrary nesting of many types of labels within each other)
+ // is not easily representable by config (arbitrary nesting of many types of elements within each other)
// and config<->xml generation will not pull its weight in work and possible bugs.
// The XML content is already validated when we get here.
public PageTemplates(List<NamedReader> readers) {
diff --git a/config-model/src/main/java/com/yahoo/vespa/model/container/xml/ManhattanContainerModelBuilder.java b/config-model/src/main/java/com/yahoo/vespa/model/container/xml/ManhattanContainerModelBuilder.java
index 15748d717d8..f6ed6c2eb7d 100644
--- a/config-model/src/main/java/com/yahoo/vespa/model/container/xml/ManhattanContainerModelBuilder.java
+++ b/config-model/src/main/java/com/yahoo/vespa/model/container/xml/ManhattanContainerModelBuilder.java
@@ -92,7 +92,7 @@ public final class ManhattanContainerModelBuilder extends ContainerModelBuilder
List<Element> accessLogElements = getAccessLogElements(spec);
if (!accessLogElements.isEmpty()) {
logManhattanInfo("Ignoring " + accessLogElements.size() +
- " access log labels in services.xml, using default yapache access logging instead.");
+ " access log elements in services.xml, using default yapache access logging instead.");
}
}
diff --git a/config-model/src/main/java/com/yahoo/vespa/model/routing/DocumentProtocol.java b/config-model/src/main/java/com/yahoo/vespa/model/routing/DocumentProtocol.java
index 5ee34748eff..344c5e16d29 100644
--- a/config-model/src/main/java/com/yahoo/vespa/model/routing/DocumentProtocol.java
+++ b/config-model/src/main/java/com/yahoo/vespa/model/routing/DocumentProtocol.java
@@ -296,7 +296,7 @@ public final class DocumentProtocol implements Protocol, Documentrouteselectorpo
/**
* Attempts to simplify all route names by removing prefixing plugin name and whatever comes before the dot (.) in
- * the second naming element. This can only be done to those routes that do not share primary name labels with
+ * the second naming element. This can only be done to those routes that do not share primary name elements with
* other routes (e.g. a search clusters with the same name as a storage cluster).
*
* @param table The routing table whose route names are to be simplified.
diff --git a/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/DomConfigPayloadBuilder.java b/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/DomConfigPayloadBuilder.java
index 8ff1708b04a..7b8f1e8ff47 100644
--- a/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/DomConfigPayloadBuilder.java
+++ b/config-model/src/main/java/com/yahoo/vespa/model/builder/xml/dom/DomConfigPayloadBuilder.java
@@ -142,7 +142,7 @@ public class DomConfigPayloadBuilder {
if (element.hasAttribute("index")) {
// Check for legacy (pre Vespa 6) usage
- throw new IllegalArgumentException("The 'index' attribute on config labels is not supported - use <item>");
+ throw new IllegalArgumentException("The 'index' attribute on config elements is not supported - use <item>");
} else if (element.hasAttribute("operation")) {
// leaf array, currently the only supported operation is 'append'
verifyLegalOperation(element);
@@ -150,7 +150,7 @@ public class DomConfigPayloadBuilder {
a.append(value);
} else if ("item".equals(name)) {
if (parentName == null)
- throw new ConfigurationRuntimeException("<item> is a reserved keyword for array and map labels");
+ throw new ConfigurationRuntimeException("<item> is a reserved keyword for array and map elements");
if (element.hasAttribute("key")) {
payloadBuilder.getMap(parentName).put(element.getAttribute("key"), value);
} else {
@@ -167,7 +167,7 @@ public class DomConfigPayloadBuilder {
// Inner value
if (element.hasAttribute("index")) {
// Check for legacy (pre Vespa 6) usage
- throw new IllegalArgumentException("The 'index' attribute on config labels is not supported - use <item>");
+ throw new IllegalArgumentException("The 'index' attribute on config elements is not supported - use <item>");
} else if (element.hasAttribute("operation")) {
// inner array, currently the only supported operation is 'append'
verifyLegalOperation(element);
@@ -204,12 +204,12 @@ public class DomConfigPayloadBuilder {
for (Element child : children)
parseElement(child, p, name);
} else if (numMatching == children.size()) {
- // Array with <item labels>
+ // Array with <item elements>
for (Element child : children) {
parseElement(child, payloadBuilder, name);
}
} else {
- throw new ConfigurationRuntimeException("<item> is a reserved keyword for array and map labels");
+ throw new ConfigurationRuntimeException("<item> is a reserved keyword for array and map elements");
}
}
}
@@ -217,7 +217,7 @@ public class DomConfigPayloadBuilder {
/**
* Adds the values and children (recursively) in the given xml element to the given {@link ConfigPayloadBuilder}.
* @param currElem The element representing a config parameter.
* @param payloadBuilder The builder to use when adding labels.
*/
private void parseElement(Element currElem, ConfigPayloadBuilder payloadBuilder, String parentName) {
List<Element> children = XML.getChildren(currElem);
@@ -217,7 +217,7 @@ public class DomConfigPayloadBuilder {
* Adds the values and children (recursively) in the given xml element to the given {@link ConfigPayloadBuilder}.
* @param currElem The element representing a config parameter.
- * @param payloadBuilder The builder to use when adding labels.
+ * @param payloadBuilder The builder to use when adding elements.
*/
private void parseElement(Element currElem, ConfigPayloadBuilder payloadBuilder, String parentName) {